@@ -1,14 +1,12 @@
 <?php
 function smarty_function_get_innerhtml($params, &$smarty)
 {
-    global $HTTP_COOKIE_VARS;
-
     $print_result = true;
     extract($params);
 
-    $cookie_name = "visibility_" . $element_name;
-    if (!empty($HTTP_COOKIE_VARS[$cookie_name])) {
-        if ($HTTP_COOKIE_VARS[$cookie_name] == 'none') {
+    $cookie_name = 'visibility_' . $element_name;
+    if (!empty($_COOKIE[$cookie_name])) {
+        if ($_COOKIE[$cookie_name] == 'none') {
             $html_result = 'show';
         } else {
             $html_result = 'hide';
@@ -29,4 +27,3 @@ function smarty_function_get_innerhtml($params, &$smarty)
         return $html_result;
     }
 }
-?>
\ No newline at end of file
