@@ -25,7 +25,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: class.custom_field.php 3307 2007-04-11 23:50:22Z balsdorf $
+// @(#) $Id: class.custom_field.php 3389 2007-10-21 01:33:24Z balsdorf $
 //
 
 require_once(APP_INC_PATH . "class.error_handler.php");
@@ -159,158 +159,170 @@ class Custom_Field
 
         $old_values = Custom_Field::getValuesByIssue($prj_id, $issue_id);
 
-        // get the types for all of the custom fields being submitted
-        $stmt = "SELECT
-                    fld_id,
-                    fld_type
-                 FROM
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "custom_field
-                 WHERE
-                    fld_id IN (" . implode(", ", Misc::escapeInteger(@array_keys($_POST['custom_fields']))) . ")";
-        $field_types = $GLOBALS["db_api"]->dbh->getAssoc($stmt);
 
-        // get the titles for all of the custom fields being submitted
-        $stmt = "SELECT
-                    fld_id,
-                    fld_title
-                 FROM
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "custom_field
-                 WHERE
-                    fld_id IN (" . implode(", ", Misc::escapeInteger(@array_keys($_POST['custom_fields']))) . ")";
-        $field_titles = $GLOBALS["db_api"]->dbh->getAssoc($stmt);
-
-        $updated_fields = array();
-        foreach ($_POST["custom_fields"] as $fld_id => $value) {
-
-            $fld_id = Misc::escapeInteger($fld_id);
-
-            // security check
-            $sql = "SELECT
-                        fld_min_role
-                    FROM
+        if ((isset($_POST['custom_fields'])) && (count($_POST['custom_fields']) > 0)) {
+            // get the types for all of the custom fields being submitted
+            $stmt = "SELECT
+                        fld_id,
+                        fld_type
+                     FROM
                         " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "custom_field
-                    WHERE
-                        fld_id = $fld_id";
-            $min_role = $GLOBALS["db_api"]->dbh->getOne($sql);
-            if ($min_role > Auth::getCurrentRole()) {
-                continue;
-            }
+                     WHERE
+                        fld_id IN (" . implode(", ", Misc::escapeInteger(@array_keys($_POST['custom_fields']))) . ")";
+            $field_types = $GLOBALS["db_api"]->dbh->getAssoc($stmt);
 
-            $option_types = array(
-                'multiple',
-                'combo'
-            );
-            if (!in_array($field_types[$fld_id], $option_types)) {
-                // check if this is a date field
-                if ($field_types[$fld_id] == 'date') {
-                    $value = $value['Year'] . "-" . $value['Month'] . "-" . $value['Day'];
-                    if ($value == '--') {
-                        $value = '';
-                    }
-                }
+            // get the titles for all of the custom fields being submitted
+            $stmt = "SELECT
+                        fld_id,
+                        fld_title
+                     FROM
+                        " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "custom_field
+                     WHERE
+                        fld_id IN (" . implode(", ", Misc::escapeInteger(@array_keys($_POST['custom_fields']))) . ")";
+            $field_titles = $GLOBALS["db_api"]->dbh->getAssoc($stmt);
 
-                // first check if there is actually a record for this field for the issue
-                $stmt = "SELECT
-                            icf_id,
-                            icf_value
-                         FROM
-                            " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field
-                         WHERE
-                            icf_iss_id=" . $issue_id . " AND
-                            icf_fld_id=$fld_id";
-                $res = $GLOBALS["db_api"]->dbh->getRow($stmt, DB_FETCHMODE_ASSOC);
-                if (PEAR::isError($res)) {
-                    Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
-                    return -1;
-                }
-                $icf_id = $res['icf_id'];
-                $icf_value = $res['icf_value'];
+            $updated_fields = array();
+            foreach ($_POST["custom_fields"] as $fld_id => $value) {
 
-                if ($icf_value == $value) {
+                $fld_id = Misc::escapeInteger($fld_id);
+
+                // security check
+                $sql = "SELECT
+                            fld_min_role
+                        FROM
+                            " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "custom_field
+                        WHERE
+                            fld_id = $fld_id";
+                $min_role = $GLOBALS["db_api"]->dbh->getOne($sql);
+                if ($min_role > Auth::getCurrentRole()) {
                     continue;
                 }
 
-                if (empty($icf_id)) {
-                    // record doesn't exist, insert new record
-                    $stmt = "INSERT INTO
-                                " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field
-                             (
-                                icf_iss_id,
-                                icf_fld_id,
-                                icf_value
-                             ) VALUES (
-                                " . $issue_id . ",
-                                $fld_id,
-                                '" . Misc::escapeString($value) . "'
-                             )";
-                    $res = $GLOBALS["db_api"]->dbh->query($stmt);
-                    if (PEAR::isError($res)) {
-                        Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
-                        return -1;
+                $option_types = array(
+                    'multiple',
+                    'combo'
+                );
+                if (!in_array($field_types[$fld_id], $option_types)) {
+                    // check if this is a date field
+                    if ($field_types[$fld_id] == 'date') {
+                        $value = $value['Year'] . "-" . $value['Month'] . "-" . $value['Day'];
+                        if ($value == '--') {
+                            $value = '';
+                        }
+                    } elseif ($field_types[$fld_id] == 'integer') {
+                        $value = Misc::escapeInteger($value);
                     }
-                } else {
-                    // record exists, update it
-                    $stmt = "UPDATE
+                    $fld_db_name = Custom_Field::getDBValueFieldNameByType($field_types[$fld_id]);
+
+                    // first check if there is actually a record for this field for the issue
+                    $stmt = "SELECT
+                                icf_id,
+                                $fld_db_name as value
+                             FROM
                                 " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field
-                             SET
-                                icf_value='" . Misc::escapeString($value) . "'
                              WHERE
-                                icf_id=$icf_id";
-                    $res = $GLOBALS["db_api"]->dbh->query($stmt);
+                                icf_iss_id=" . $issue_id . " AND
+                                icf_fld_id=$fld_id";
+                    $res = $GLOBALS["db_api"]->dbh->getRow($stmt, DB_FETCHMODE_ASSOC);
                     if (PEAR::isError($res)) {
                         Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
                         return -1;
                     }
-                }
-                if ($field_types[$fld_id] == 'textarea') {
-                    $updated_fields[$field_titles[$fld_id]] = '';
-                } else {
-                    $updated_fields[$field_titles[$fld_id]] = History::formatChanges($icf_value, $value);
-                }
-            } else {
-                $old_value = Custom_Field::getDisplayValue($_POST['issue_id'], $fld_id, true);
+                    $icf_id = $res['icf_id'];
+                    $old_value = $res['value'];
 
-                if (!is_array($old_value)) {
-                    $old_value = array($old_value);
-                }
-                if (!is_array($value)) {
-                    $value = array($value);
-                }
-                if ((count(array_diff($old_value, $value)) > 0) || (count(array_diff($value, $old_value)) > 0)) {
-
-                    $old_display_value = Custom_Field::getDisplayValue($_POST['issue_id'], $fld_id);
-                    // need to remove all associated options from issue_custom_field and then
-                    // add the selected options coming from the form
-                    Custom_Field::removeIssueAssociation($fld_id, $_POST["issue_id"]);
-                    if (@count($value) > 0) {
-                        Custom_Field::associateIssue($_POST["issue_id"], $fld_id, $value);
+                    if ($old_value == $value) {
+                        continue;
                     }
-                    $new_display_value = Custom_Field::getDisplayValue($_POST['issue_id'], $fld_id);
-                    $updated_fields[$field_titles[$fld_id]] = History::formatChanges($old_display_value, $new_display_value);
-                }
-            }
-        }
 
-        Workflow::handleCustomFieldsUpdated($prj_id, $issue_id, $old_values, Custom_Field::getValuesByIssue($prj_id, $issue_id));
-        Issue::markAsUpdated($_POST["issue_id"]);
-        // need to save a history entry for this
+                    if (empty($value)) {
+                        $value = 'NULL';
+                    } else {
+                        $value = "'" . Misc::escapeString($value) . "'";
+                    }
 
-        if (count($updated_fields) > 0) {
-            // log the changes
-            $changes = '';
-            $i = 0;
-            foreach ($updated_fields as $key => $value) {
-                if ($i > 0) {
-                    $changes .= "; ";
-                }
-                if (!empty($value)) {
-                    $changes .= "$key: $value";
+                    if (empty($icf_id)) {
+                        // record doesn't exist, insert new record
+                        $stmt = "INSERT INTO
+                                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field
+                                 (
+                                    icf_iss_id,
+                                    icf_fld_id,
+                                    $fld_db_name
+                                 ) VALUES (
+                                    " . $issue_id . ",
+                                    $fld_id,
+                                    $value
+                                 )";
+                        $res = $GLOBALS["db_api"]->dbh->query($stmt);
+                        if (PEAR::isError($res)) {
+                            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+                            return -1;
+                        }
+                    } else {
+                        // record exists, update it
+                        $stmt = "UPDATE
+                                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field
+                                 SET
+                                    $fld_db_name=$value
+                                 WHERE
+                                    icf_id=$icf_id";
+                        $res = $GLOBALS["db_api"]->dbh->query($stmt);
+                        if (PEAR::isError($res)) {
+                            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+                            return -1;
+                        }
+                    }
+                    if ($field_types[$fld_id] == 'textarea') {
+                        $updated_fields[$field_titles[$fld_id]] = '';
+                    } else {
+                        $updated_fields[$field_titles[$fld_id]] = History::formatChanges($old_value, $value);
+                    }
                 } else {
-                    $changes .= "$key";
+                    $old_value = Custom_Field::getDisplayValue($_POST['issue_id'], $fld_id, true);
+
+                    if (!is_array($old_value)) {
+                        $old_value = array($old_value);
+                    }
+                    if (!is_array($value)) {
+                        $value = array($value);
+                    }
+                    if ((count(array_diff($old_value, $value)) > 0) || (count(array_diff($value, $old_value)) > 0)) {
+
+                        $old_display_value = Custom_Field::getDisplayValue($_POST['issue_id'], $fld_id);
+                        // need to remove all associated options from issue_custom_field and then
+                        // add the selected options coming from the form
+                        Custom_Field::removeIssueAssociation($fld_id, $_POST["issue_id"]);
+                        if (@count($value) > 0) {
+                            Custom_Field::associateIssue($_POST["issue_id"], $fld_id, $value);
+                        }
+                        $new_display_value = Custom_Field::getDisplayValue($_POST['issue_id'], $fld_id);
+                        $updated_fields[$field_titles[$fld_id]] = History::formatChanges($old_display_value, $new_display_value);
+                    }
                 }
-                $i++;
             }
-            History::add($_POST["issue_id"], Auth::getUserID(), History::getTypeID('custom_field_updated'), ev_gettext('Custom field updated (%1$s) by %2$s', $changes, User::getFullName(Auth::getUserID())));
+
+            Workflow::handleCustomFieldsUpdated($prj_id, $issue_id, $old_values, Custom_Field::getValuesByIssue($prj_id, $issue_id));
+            Issue::markAsUpdated($_POST["issue_id"]);
+            // need to save a history entry for this
+
+            if (count($updated_fields) > 0) {
+                // log the changes
+                $changes = '';
+                $i = 0;
+                foreach ($updated_fields as $key => $value) {
+                    if ($i > 0) {
+                        $changes .= "; ";
+                    }
+                    if (!empty($value)) {
+                        $changes .= "$key: $value";
+                    } else {
+                        $changes .= "$key";
+                    }
+                    $i++;
+                }
+                History::add($_POST["issue_id"], Auth::getUserID(), History::getTypeID('custom_field_updated'), ev_gettext('Custom field updated (%1$s) by %2$s', $changes, User::getFullName(Auth::getUserID())));
+            }
         }
         return 1;
     }
@@ -337,18 +349,27 @@ class Custom_Field
             $value = array($value);
         }
         foreach ($value as $item) {
+            if ($fld_details['fld_type'] == 'integer') {
+                $item = Misc::escapeInteger($item);
+            } else {
+                $item = "'" . Misc::escapeString($item) . "'";
+            }
             $stmt = "INSERT INTO
                         " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field
                      (
                         icf_iss_id,
                         icf_fld_id,
-                        icf_value
+                        " . Custom_Field::getDBValueFieldNameByType($fld_details['fld_type']) . "
                      ) VALUES (
                         " . Misc::escapeInteger($iss_id) . ",
                         " . Misc::escapeInteger($fld_id) . ",
-                        '" . Misc::escapeString($item) . "'
+                        $item
                      )";
-            $GLOBALS["db_api"]->dbh->query($stmt);
+            $res = $GLOBALS["db_api"]->dbh->query($stmt);
+            if (PEAR::isError($res)) {
+                Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+                return false;
+            }
         }
         return true;
     }
@@ -410,6 +431,19 @@ class Custom_Field
                         $res[$i]['controlling_field_name'] = $backend->getControllingCustomFieldName();
                         $res[$i]['hide_when_no_options'] = $backend->hideWhenNoOptions();
                     }
+                    // check if the backend implements "isRequired"
+                    if ((is_object($backend)) && (method_exists($backend, 'isRequired'))) {
+                        $res[$i]['fld_report_form_required'] = $backend->isRequired($res[$i]['fld_id'], 'report');
+                        $res[$i]['fld_anonymous_form_required'] = $backend->isRequired($res[$i]['fld_id'], 'anonymous');
+                        $res[$i]['fld_close_form_required'] = $backend->isRequired($res[$i]['fld_id'], 'close');
+                    }
+                    if ((is_object($backend)) && (method_exists($backend, 'getValidationJS'))) {
+                        $res[$i]['validation_js'] = $backend->getValidationJS($res[$i]['fld_id'], $form_type);
+                    } else {
+                        $res[$i]['validation_js'] = '';
+                    }
+
+
                     $res[$i]["field_options"] = Custom_Field::getOptions($res[$i]["fld_id"]);
                 }
                 return $res;
@@ -440,7 +474,7 @@ class Custom_Field
 
         $backend = Custom_Field::getBackend($fld_id);
         if ((is_object($backend)) && (method_exists($backend, 'getList'))) {
-            $values = $backend->getList($fld_id);
+            $values = $backend->getList($fld_id, false);
             $returns[$fld_id . $value] = @$values[$value];
             return @$values[$value];
         } else {
@@ -490,7 +524,7 @@ class Custom_Field
 
         $backend = Custom_Field::getBackend($fld_id);
         if ((is_object($backend)) && (method_exists($backend, 'getList'))) {
-            $values = $backend->getList($fld_id);
+            $values = $backend->getList($fld_id, false);
             $key = array_search($value, $values);
             $returns[$fld_id . $value] = $key;
             return $key;
@@ -530,7 +564,7 @@ class Custom_Field
      * @param   integer $usr_id The ID of the user who is going to be viewing this list.
      * @return  array The list of custom fields
      */
-    function getListByIssue($prj_id, $iss_id, $usr_id = false)
+    function getListByIssue($prj_id, $iss_id, $usr_id = false, $form_type = false)
     {
         if ($usr_id == false) {
             $usr_id = Auth::getUserID();
@@ -547,7 +581,8 @@ class Custom_Field
                     fld_type,
                     fld_report_form_required,
                     fld_anonymous_form_required,
-                    icf_value,
+                    fld_close_form_required,
+                    " . Custom_Field::getDBValueFieldSQL() . " as value,
                     fld_min_role
                  FROM
                     (
@@ -562,7 +597,11 @@ class Custom_Field
                  WHERE
                     pcf_fld_id=fld_id AND
                     pcf_prj_id=" .  Misc::escapeInteger($prj_id) . " AND
-                    fld_min_role <= " . $usr_role . "
+                    fld_min_role <= " . $usr_role;
+        if ($form_type != '') {
+            $stmt .= " AND\nfld_" .  Misc::escapeString($form_type) . "=1";
+        }
+        $stmt .= "
                  ORDER BY
                     fld_rank ASC";
         $res = $GLOBALS["db_api"]->dbh->getAll($stmt, DB_FETCHMODE_ASSOC);
@@ -575,13 +614,19 @@ class Custom_Field
             } else {
                 $fields = array();
                 for ($i = 0; $i < count($res); $i++) {
-                    if (($res[$i]['fld_type'] == 'text') || ($res[$i]['fld_type'] == 'textarea') || ($res[$i]['fld_type'] == 'date')) {
-                        $fields[] = $res[$i];
-                    } elseif ($res[$i]["fld_type"] == "combo") {
-                        $res[$i]["selected_cfo_id"] = $res[$i]["icf_value"];
-                        $res[$i]["icf_value"] = Custom_Field::getOptionValue($res[$i]["fld_id"], $res[$i]["icf_value"]);
+                    if ($res[$i]["fld_type"] == "combo") {
+                        $res[$i]["selected_cfo_id"] = $res[$i]["value"];
+                        $res[$i]["original_value"] = $res[$i]["value"];
+                        $res[$i]["value"] = Custom_Field::getOptionValue($res[$i]["fld_id"], $res[$i]["value"]);
                         $res[$i]["field_options"] = Custom_Field::getOptions($res[$i]["fld_id"]);
+
+                        // add the select option to the list of values if it isn't on the list (useful for fields with active and non-active items)
+                        if (!in_array($res[$i]['value'], $res[$i]['field_options'])) {
+                            $res[$i]['field_options'][$res[$i]['original_value']] = Custom_Field::getOptionValue($res[$i]['fld_id'], $res[$i]['original_value']);
+                        }
+
                         $fields[] = $res[$i];
+
                     } elseif ($res[$i]['fld_type'] == 'multiple') {
                         // check whether this field is already in the array
                         $found = 0;
@@ -591,15 +636,24 @@ class Custom_Field
                                 $found_index = $y;
                             }
                         }
+                        $original_value = $res[$i]['value'];
                         if (!$found) {
-                            $res[$i]["selected_cfo_id"] = array($res[$i]["icf_value"]);
-                            $res[$i]["icf_value"] = Custom_Field::getOptionValue($res[$i]["fld_id"], $res[$i]["icf_value"]);
+                            $res[$i]["selected_cfo_id"] = array($res[$i]["value"]);
+                            $res[$i]["value"] = Custom_Field::getOptionValue($res[$i]["fld_id"], $res[$i]["value"]);
                             $res[$i]["field_options"] = Custom_Field::getOptions($res[$i]["fld_id"]);
                             $fields[] = $res[$i];
+                            $found_index = count($fields) - 1;
                         } else {
-                            $fields[$found_index]['icf_value'] .= ', ' . Custom_Field::getOptionValue($res[$i]["fld_id"], $res[$i]["icf_value"]);
-                            $fields[$found_index]['selected_cfo_id'][] = $res[$i]["icf_value"];
+                            $fields[$found_index]['value'] .= ', ' . Custom_Field::getOptionValue($res[$i]["fld_id"], $res[$i]["value"]);
+                            $fields[$found_index]['selected_cfo_id'][] = $res[$i]["value"];
                         }
+
+                        // add the select option to the list of values if it isn't on the list (useful for fields with active and non-active items)
+                        if (!in_array($original_value, $fields[$found_index]['field_options'])) {
+                            $fields[$found_index]['field_options'][$original_value] = Custom_Field::getOptionValue($res[$i]['fld_id'], $original_value);
+                        }
+                    } else {
+                        $fields[] = $res[$i];
                     }
                 }
                 foreach ($fields as $key => $field) {
@@ -610,6 +664,18 @@ class Custom_Field
                         $fields[$key]['controlling_field_name'] = $backend->getControllingCustomFieldName();
                         $fields[$key]['hide_when_no_options'] = $backend->hideWhenNoOptions();
                     }
+
+                    // check if the backend implements "isRequired"
+                    if ((is_object($backend)) && (method_exists($backend, 'isRequired'))) {
+                        $fields[$key]['fld_report_form_required'] = $backend->isRequired($fields[$key]['fld_id'], 'report', $iss_id);
+                        $fields[$key]['fld_anonymous_form_required'] = $backend->isRequired($fields[$key]['fld_id'], 'anonymous', $iss_id);
+                        $fields[$key]['fld_close_form_required'] = $backend->isRequired($fields[$key]['fld_id'], 'close', $iss_id);
+                    }
+                    if ((is_object($backend)) && (method_exists($backend, 'getValidationJS'))) {
+                        $fields[$key]['validation_js'] = $backend->getValidationJS($fields[$key]['fld_id'], $form_type, $iss_id);
+                    } else {
+                        $fields[$key]['validation_js'] = '';
+                    }
                 }
                 return $fields;
             }
@@ -630,17 +696,17 @@ class Custom_Field
         $values = array();
         $list = Custom_Field::getListByIssue($prj_id, $iss_id);
         foreach ($list as $field) {
-            if (in_array($field['fld_type'], array('text', 'textarea'))) {
-                $values[$field['fld_id']] = $field['icf_value'];
-            } elseif ($field['fld_type'] == 'combo') {
+            if ($field['fld_type'] == 'combo') {
                 $values[$field['fld_id']] = array(
-                    $field['selected_cfo_id'] => $field['icf_value']
+                    $field['selected_cfo_id'] => $field['value']
                 );
             } elseif ($field['fld_type'] == 'multiple') {
                 $selected = $field['selected_cfo_id'];
                 foreach ($selected as $cfo_id) {
                     $values[$field['fld_id']][$cfo_id] = @$field['field_options'][$cfo_id];
                 }
+            } else {
+                $values[$field['fld_id']] = $field['value'];
             }
         }
         return $values;
@@ -720,6 +786,12 @@ class Custom_Field
         if (empty($_POST["anon_form_required"])) {
             $_POST["anon_form_required"] = 0;
         }
+        if (empty($_POST["close_form"])) {
+            $_POST["close_form"] = 0;
+        }
+        if (empty($_POST["close_form_required"])) {
+            $_POST["close_form_required"] = 0;
+        }
         if (empty($_POST["list_display"])) {
             $_POST["list_display"] = 0;
         }
@@ -739,6 +811,8 @@ class Custom_Field
                     fld_report_form_required,
                     fld_anonymous_form,
                     fld_anonymous_form_required,
+                    fld_close_form,
+                    fld_close_form_required,
                     fld_list_display,
                     fld_min_role,
                     fld_rank,
@@ -751,6 +825,8 @@ class Custom_Field
                     " . Misc::escapeInteger($_POST["report_form_required"]) . ",
                     " . Misc::escapeInteger($_POST["anon_form"]) . ",
                     " . Misc::escapeInteger($_POST["anon_form_required"]) . ",
+                    " . Misc::escapeInteger($_POST["close_form"]) . ",
+                    " . Misc::escapeInteger($_POST["close_form_required"]) . ",
                     " . Misc::escapeInteger($_POST["list_display"]) . ",
                     " . Misc::escapeInteger($_POST["min_role"]) . ",
                     " . Misc::escapeInteger($_POST['rank']) . ",
@@ -879,13 +955,14 @@ class Custom_Field
      *
      * @access  public
      * @param   integer $fld_id The custom field ID
+     * @param   boolean $force_refresh If the details must be loaded again from the database
      * @return  array The custom field details
      */
-    function getDetails($fld_id)
+    function getDetails($fld_id, $force_refresh = false)
     {
         static $returns;
 
-        if (isset($returns[$fld_id])) {
+        if ((isset($returns[$fld_id])) && ($force_refresh == false)) {
             return $returns[$fld_id];
         }
 
@@ -1021,6 +1098,12 @@ class Custom_Field
         if (empty($_POST["list_display"])) {
             $_POST["list_display"] = 0;
         }
+        if (empty($_POST["close_form"])) {
+            $_POST["close_form"] = 0;
+        }
+        if (empty($_POST["close_form_required"])) {
+            $_POST["close_form_required"] = 0;
+        }
         if (empty($_POST["min_role"])) {
             $_POST["min_role"] = 1;
         }
@@ -1038,6 +1121,8 @@ class Custom_Field
                     fld_report_form_required=" . Misc::escapeInteger($_POST["report_form_required"]) . ",
                     fld_anonymous_form=" . Misc::escapeInteger($_POST["anon_form"]) . ",
                     fld_anonymous_form_required=" . Misc::escapeInteger($_POST["anon_form_required"]) . ",
+                    fld_close_form=" . Misc::escapeInteger($_POST["close_form"]) . ",
+                    fld_close_form_required=" . Misc::escapeInteger($_POST["close_form_required"]) . ",
                     fld_list_display=" . Misc::escapeInteger($_POST["list_display"]) . ",
                     fld_min_role=" . Misc::escapeInteger($_POST['min_role']) . ",
                     fld_rank = " . Misc::escapeInteger($_POST['rank']) . ",
@@ -1059,11 +1144,16 @@ class Custom_Field
                             cfo_fld_id=" . Misc::escapeInteger($_POST["id"]);
                 $current_options = $GLOBALS["db_api"]->dbh->getCol($stmt);
             }
-            // gotta remove all custom field options if the field is being changed from a combo box to a text field
-            if (($old_details["fld_type"] != $_POST["field_type"]) &&
-                      (!in_array($old_details['fld_type'], array('text', 'textarea'))) &&
+            if ($old_details["fld_type"] != $_POST["field_type"]) {
+                // gotta remove all custom field options if the field is being changed from a combo box to a text field
+                if ((!in_array($old_details['fld_type'], array('text', 'textarea'))) &&
                       (!in_array($_POST["field_type"], array('combo', 'multiple')))) {
-                Custom_Field::removeOptionsByFields($_POST["id"]);
+                   Custom_Field::removeOptionsByFields($_POST["id"]);
+                }
+                if (in_array($_POST['field_type'], array('text', 'textarea', 'date', 'integer'))) {
+                    // update values for all other option types
+                    Custom_Field::updateValuesForNewType($_POST['id']);
+                }
             }
             // update the custom field options, if any
             if (($_POST["field_type"] == "combo") || ($_POST["field_type"] == "multiple")) {
@@ -1352,7 +1442,7 @@ class Custom_Field
         $sql = "SELECT
                     fld_id,
                     fld_type,
-                    icf_value
+                    " . Custom_Field::getDBValueFieldSQL() . " as value
                 FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "custom_field,
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field
@@ -1367,14 +1457,14 @@ class Custom_Field
         } else {
             $values = array();
             for ($i = 0; $i < count($res); $i++) {
-                if (($res[$i]['fld_type'] == 'text') || ($res[$i]['fld_type'] == 'textarea')) {
-                    $values[] = $res[$i]['icf_value'];
-                } elseif (($res[$i]["fld_type"] == "combo") || ($res[$i]['fld_type'] == 'multiple')) {
+                if (($res[$i]["fld_type"] == "combo") || ($res[$i]['fld_type'] == 'multiple')) {
                     if ($raw) {
-                        $values[] = $res[$i]['icf_value'];
+                        $values[] = $res[$i]['value'];
                     } else {
-                        $values[] = Custom_Field::getOptionValue($res[$i]["fld_id"], $res[$i]["icf_value"]);
+                        $values[] = Custom_Field::getOptionValue($res[$i]["fld_id"], $res[$i]["value"]);
                     }
+                } else {
+                    $values[] = $res[$i]['value'];
                 }
             }
             if ($raw) {
@@ -1563,7 +1653,11 @@ class Custom_Field
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field
                 WHERE
                     icf_fld_id = " . Misc::escapeInteger($fld_id) . " AND
-                    icf_value LIKE '%" . Misc::escapeString($search) . "%'";
+                    (
+                        icf_value LIKE '%" . Misc::escapeString($search) . "%' OR
+                        icf_value_integer LIKE '%" . Misc::escapeInteger($search) . "%' OR
+                        icf_value_date LIKE '%" . Misc::escapeString($search) . "%'
+                    )";
         $res = $GLOBALS["db_api"]->dbh->getCol($sql);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
@@ -1605,13 +1699,79 @@ class Custom_Field
         $prj_id = Issue::getProjectID($issue_id);
         $fields = Custom_Field::getListByIssue($prj_id, $issue_id, APP_SYSTEM_USER_ID);
         foreach ($fields as $field) {
-            if (empty($field['icf_value'])) {
+            if (empty($field['value'])) {
                 Custom_Field::removeIssueAssociation($field['fld_id'], $issue_id);
                 Custom_Field::associateIssue($issue_id, $field['fld_id'], '');
             }
         }
     }
 
+
+    /**
+     * Returns the name of the db field this custom field uses based on the type.
+     *
+     * @param   string $type
+     * @return  string
+     */
+    function getDBValueFieldNameByType($type)
+    {
+        switch ($type) {
+            case 'date':
+                return 'icf_value_date';
+            case 'integer':
+                return 'icf_value_integer';
+            default:
+                return 'icf_value';
+        }
+    }
+
+
+    function getDBValueFieldSQL()
+    {
+        return "(IF(fld_type = 'date', icf_value_date, IF(fld_type = 'integer', icf_value_integer, icf_value)))";
+    }
+
+
+    /**
+     * Analyzes the contents of the issue_custom_field and updates
+     * contents based on the fld_type.
+     *
+     * @param   integer $fld_id
+     */
+    function updateValuesForNewType($fld_id)
+    {
+        $details = Custom_Field::getDetails($fld_id, true);
+        $db_field_name = Custom_Field::getDBValueFieldNameByType($details['fld_type']);
+
+
+        $sql = "UPDATE
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field
+                SET
+                    ";
+        if ($details['fld_type'] == 'integer') {
+            $sql .= "$db_field_name = IFNULL(icf_value, IFNULL(icf_value_date, NULL)),
+                    icf_value = NULL,
+                    icf_value_date = NULL";
+        } elseif ($details['fld_type'] == 'date') {
+            $sql .= "$db_field_name = IFNULL(icf_value, IFNULL(icf_value_date, NULL)),
+                    icf_value = NULL,
+                    icf_value_integer = NULL";
+        } else {
+            $sql .= "$db_field_name = IFNULL(icf_value_integer, IFNULL(icf_value_date, NULL)),
+                    icf_value_integer = NULL,
+                    icf_value_date = NULL";
+        }
+        $sql .= "
+                WHERE
+                    $db_field_name IS NULL AND
+                    icf_fld_id = " . Misc::escapeInteger($fld_id);
+        $res = $GLOBALS["db_api"]->dbh->query($sql);
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            return false;
+        }
+        return true;
+    }
 }
 
 // benchmarking the included file (aka setup time)
