@@ -229,7 +229,7 @@ class Mail_API
         $address = Mime_Helper::encodeValue($address);
         $t = Mail_RFC822::parseAddressList($address, null, null, false);
         if (PEAR::isError($t)) {
-            Error_Handler::logError(array($t->getMessage(), $t->getDebugInfo()), __FILE__, __LINE__);
+            return $t;
         }
         if ($multiple) {
             $returns = array();
@@ -264,6 +264,9 @@ class Mail_API
     function getEmailAddress($address)
     {
         $info = Mail_API::getAddressInfo($address);
+        if (PEAR::isError($info)) {
+            return $info;
+        }
         return $info['email'];
     }
 
@@ -279,6 +282,9 @@ class Mail_API
     function getName($address, $multiple = false)
     {
         $info = Mail_API::getAddressInfo($address, true);
+        if (PEAR::isError($info)) {
+            return $info;
+        }
         $returns = array();
         foreach ($info as $row) {
             if (!empty($row['sender_name'])) {
@@ -476,9 +482,10 @@ class Mail_API
      * @param   integer $issue_id The issue ID
      * @param   string $to The recipient of the message
      * @param   string $body The body of the message
+     * @param   headers $headers The headers of the message
      * @return  string The body of the message with the warning message, if appropriate
      */
-    function addWarningMessage($issue_id, $to, $body)
+    function addWarningMessage($issue_id, $to, $body, $headers)
     {
         $setup = Setup::load();
         if ((@$setup['email_routing']['status'] == 'enabled') &&
@@ -496,9 +503,14 @@ class Mail_API
                     return $body;
                 } else {
                     if (!Support::isAllowedToEmail($issue_id, $recipient_email)) {
-                        return Mail_API::getWarningMessage('blocked') . "\n\n" . $body;
+                        $warning = Mail_API::getWarningMessage('blocked');
                     } else {
-                        return Mail_API::getWarningMessage('allowed') . "\n\n" . $body;
+                        $warning = Mail_API::getWarningMessage('allowed');
+                    }
+                    if (@$headers['Content-Transfer-Encoding'] == 'base64') {
+                        return base64_encode($warning . "\n\n" . trim(base64_decode($body)));
+                    } else {
+                        return $warning . "\n\n" . $body;
                     }
                 }
             }
@@ -730,12 +742,13 @@ class Mail_API
                     $support_levels = Customer::getSupportLevelAssocList($prj_id);
                 }
                 $customer_id = Issue::getCustomerID($issue_id);
+                $contract_id = Issue::getContractID($issue_id);
                 if (!empty($customer_id)) {
-                    $customer_details = Customer::getDetails($prj_id, $customer_id);
+                    $customer_details = Customer::getDetails($prj_id, $customer_id, false, $contract_id);
                     $new_headers['X-Eventum-Customer'] = $customer_details['customer_name'];
                 }
                 if (count($support_levels) > 0) {
-                    $new_headers['X-Eventum-Level'] = $support_levels[Customer::getSupportLevelID($prj_id, $customer_id)];
+                    $new_headers['X-Eventum-Level'] = $support_levels[Customer::getSupportLevelID($prj_id, $customer_id, $contract_id)];
                 }
             }
             // add assignee header
