@@ -139,6 +139,7 @@ CREATE TABLE %TABLE_PREFIX%issue (
   iss_id int(11) unsigned NOT NULL auto_increment,
   iss_customer_id int(11) unsigned NULL,
   iss_customer_contact_id int(11) unsigned NULL,
+  iss_customer_contract_id varchar(50) NULL,
   iss_usr_id int(10) unsigned NOT NULL default 0,
   iss_grp_id int(11) unsigned NULL default NULL,
   iss_prj_id int(11) unsigned NOT NULL default 0,
@@ -505,7 +506,7 @@ CREATE TABLE %TABLE_PREFIX%user (
 INSERT INTO %TABLE_PREFIX%user (usr_id, usr_created_date, usr_status, usr_password, usr_full_name, usr_email, usr_preferences) VALUES (1, NOW(), 'inactive', '14589714398751513457adf349173434', 'system', 'system-account@example.com', '');
 INSERT INTO %TABLE_PREFIX%user (usr_id, usr_created_date, usr_password, usr_full_name, usr_email, usr_preferences) VALUES (2, NOW(), '21232f297a57a5a743894a0e4a801fc3', 'Admin User', 'admin@example.com', '');
 
-DROP TABLE IF EXISTS %TABLE_PREFIX%custom_field;
+    DROP TABLE IF EXISTS %TABLE_PREFIX%custom_field;
 CREATE TABLE %TABLE_PREFIX%custom_field (
   fld_id int(10) unsigned NOT NULL auto_increment,
   fld_title varchar(32) NOT NULL default '',
@@ -515,6 +516,8 @@ CREATE TABLE %TABLE_PREFIX%custom_field (
   fld_report_form_required int(1) NOT NULL default 0,
   fld_anonymous_form int(1) NOT NULL default 1,
   fld_anonymous_form_required int(1) NOT NULL default 0,
+  fld_close_form tinyint(1) NOT NULL DEFAULT 0,
+  fld_close_form_required tinyint(1) NOT NULL DEFAULT 0,
   fld_list_display tinyint(1) NOT NULL default 0,
   fld_min_role tinyint(1) NOT NULL default 0,
   fld_rank smallint(2) NOT NULL default 0,
@@ -537,6 +540,8 @@ CREATE TABLE %TABLE_PREFIX%issue_custom_field (
   icf_iss_id int(10) unsigned NOT NULL default 0,
   icf_fld_id int(10) unsigned NOT NULL default 0,
   icf_value text default NULL,
+  icf_value_integer int(11) default NULL,
+  icf_value_date date default NULL,
   PRIMARY KEY  (icf_id),
   KEY icf_iss_id (icf_iss_id),
   KEY icf_fld_id (icf_fld_id)
